@@ -29,6 +29,7 @@
 #include <QWebHistoryItem>
 #include <QWebSettings>
 
+#include "kwebkitpart_debug.h"
 #include "kwebkitpart_ext.h"
 #include "sslinfodialog_p.h"
 #include "webview.h"
@@ -41,36 +42,35 @@
 #include "ui/featurepermissionbar.h"
 #include "settings/webkitsettings.h"
 
-#include <kdeversion.h>
 #include <kcodecaction.h>
 #include <kio/global.h>
-#include <kglobal.h>
 #include <kiconloader.h>
 
-#include <KDE/KActionCollection>
-#include <KDE/KAboutData>
-#include <KDE/KComponentData>
-#include <KDE/KDebug>
-#include <KDE/KUrlLabel>
-#include <KDE/KMessageBox>
-#include <KDE/KStringHandler>
-#include <KDE/KMenu>
-#include <KDE/KWebWallet>
-#include <KDE/KToolInvocation>
-#include <KDE/KAcceleratorManager>
-#include <KDE/KStatusBar>
-#include <KDE/KFileItem>
-#include <KDE/KMessageWidget>
-#include <KDE/KProtocolInfo>
-#include <KDE/KToggleAction>
+#include <KActionCollection>
+#include <KAboutData>
+#include <KComponentData>
+#include <KUrlLabel>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KStringHandler>
+#include <KMenu>
+#include <KWebWallet>
+#include <KToolInvocation>
+#include <KAcceleratorManager>
+#include <KStatusBar>
+#include <KFileItem>
+#include <KMessageWidget>
+#include <KProtocolInfo>
+#include <KToggleAction>
 #include <KParts/StatusBarExtension>
-#include <KDE/KAction>
-#include <KDE/KIcon>
-#include <KDE/KShortcut>
+#include <KAction>
+#include <KShortcut>
 #include <KParts/GUIActivateEvent>
+#include <KSharedConfig>
 
 #include <QUrl>
 #include <QFile>
+#include <QIcon>
 #include <QTextCodec>
 #include <QCoreApplication>
 #include <QVBoxLayout>
@@ -79,7 +79,7 @@
 #define QL1S(x)  QLatin1String(x)
 #define QL1C(x)  QLatin1Char(x)
 
-K_GLOBAL_STATIC_WITH_ARGS(QUrl, globalBlankUrl, ("about:blank"))
+Q_GLOBAL_STATIC_WITH_ARGS(QUrl, globalBlankUrl, ("about:blank"))
 
 static inline int convertStr2Int(const QString& value)
 {
@@ -121,15 +121,6 @@ KWebKitPart::KWebKitPart(QWidget *parentWidget, QObject *parent,
 //    KComponentData componentData(&about);
     setComponentData(about, false /*don't load plugins yet*/);
 
-    // NOTE: If the application does not set its version number, we automatically
-    // set it to KDE's version number so that the default user-agent string contains
-    // proper application version number information. See QWebPage::userAgentForUrl...
-    if (QCoreApplication::applicationVersion().isEmpty())
-        QCoreApplication::setApplicationVersion(QString("%1.%2.%3")
-                                                .arg(KDE::versionMajor())
-                                                .arg(KDE::versionMinor())
-                                                .arg(KDE::versionRelease()));
-
     setXMLFile(QL1S("kwebkitpart.rc"));
 
     // Create this KPart's widget
@@ -217,32 +208,32 @@ void KWebKitPart::initActions()
     actionCollection()->addAction("saveFrame", action);
     connect(action, SIGNAL(triggered(bool)), m_browserExtension, SLOT(slotSaveFrame()));
 
-    action = new QAction(KIcon("document-print-preview"), i18n("Print Preview"), this);
+    action = new QAction(QIcon::fromTheme(QStringLiteral("document-print-preview")), i18n("Print Preview"), this);
     actionCollection()->addAction("printPreview", action);
     connect(action, SIGNAL(triggered(bool)), m_browserExtension, SLOT(slotPrintPreview()));
 
-    action = new QAction(KIcon("zoom-in"), i18nc("zoom in action", "Zoom In"), this);
+    action = new QAction(QIcon::fromTheme(QStringLiteral("zoom-in")), i18nc("zoom in action", "Zoom In"), this);
     actionCollection()->addAction("zoomIn", action);
     actionCollection()->setDefaultShortcuts(action,
                                             QList<QKeySequence>() << QKeySequence(Qt::CTRL+Qt::Key_Plus)
                                                                   << QKeySequence(Qt::CTRL+Qt::Key_Equal));
     connect(action, SIGNAL(triggered(bool)), m_browserExtension, SLOT(zoomIn()));
 
-    action = new QAction(KIcon("zoom-out"), i18nc("zoom out action", "Zoom Out"), this);
+    action = new QAction(QIcon::fromTheme(QStringLiteral("zoom-out")), i18nc("zoom out action", "Zoom Out"), this);
     actionCollection()->addAction("zoomOut", action);
     actionCollection()->setDefaultShortcuts(action,
                                             QList<QKeySequence>() << QKeySequence(Qt::CTRL+Qt::Key_Minus)
                                                                   << QKeySequence(Qt::CTRL+Qt::Key_Underscore));
     connect(action, SIGNAL(triggered(bool)), m_browserExtension, SLOT(zoomOut()));
 
-    action = new QAction(KIcon("zoom-original"), i18nc("reset zoom action", "Actual Size"), this);
+    action = new QAction(QIcon::fromTheme(QStringLiteral("zoom-original")), i18nc("reset zoom action", "Actual Size"), this);
     actionCollection()->addAction("zoomNormal", action);
     actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL+Qt::Key_0));
     connect(action, SIGNAL(triggered(bool)), m_browserExtension, SLOT(zoomNormal()));
 
     action = new QAction(i18n("Zoom Text Only"), this);
     action->setCheckable(true);
-    KConfigGroup cgHtml(KGlobal::config(), "HTML Settings");
+    KConfigGroup cgHtml(KSharedConfig::openConfig(), "HTML Settings");
     bool zoomTextOnly = cgHtml.readEntry("ZoomTextOnly", false);
     action->setChecked(zoomTextOnly);
     actionCollection()->addAction("zoomTextOnly", action);
@@ -260,7 +251,7 @@ void KWebKitPart::initActions()
     action->setShortcutContext(Qt::WidgetShortcut);
     m_webView->addAction(action);
 
-    KCodecAction *codecAction = new KCodecAction( KIcon("character-set"), i18n( "Set &Encoding" ), this, true );
+    KCodecAction *codecAction = new KCodecAction( QIcon::fromTheme(QStringLiteral("character-set")), i18n( "Set &Encoding" ), this, true );
     actionCollection()->addAction( "setEncoding", codecAction );
     connect(codecAction, SIGNAL(triggered(QTextCodec*)), SLOT(slotSetTextEncoding(QTextCodec*)));
 
@@ -357,7 +348,7 @@ bool KWebKitPart::openUrl(const QUrl &_u)
 {
     QUrl u (_u);
 
-    kDebug() << u;
+    qCDebug(KWEBKITPART_LOG) << u;
 
     // Ignore empty requests...
     if (u.isEmpty())
@@ -484,8 +475,8 @@ void KWebKitPart::slotFrameLoadFinished(bool ok)
 
     if (ok) {
         const QUrl currentUrl (frame->baseUrl().resolved(frame->url()));
-        // kDebug() << "mainframe:" << m_webView->page()->mainFrame() << "frame:" << sender();
-        // kDebug() << "url:" << frame->url() << "base url:" << frame->baseUrl() << "request url:" << frame->requestedUrl();
+        // qCDebug(KWEBKITPART_LOG) << "mainframe:" << m_webView->page()->mainFrame() << "frame:" << sender();
+        // qCDebug(KWEBKITPART_LOG) << "url:" << frame->url() << "base url:" << frame->baseUrl() << "request url:" << frame->requestedUrl();
         if (currentUrl != *globalBlankUrl) {
             m_hasCachedFormData = false;
 
@@ -540,7 +531,7 @@ void KWebKitPart::slotMainFrameLoadFinished (bool ok)
         QUrl shortcutIconUrl;
         if (!element.isNull()) {
             shortcutIconUrl = frame->baseUrl().resolved(QUrl(element.attribute("href")));
-            //kDebug() << "setting favicon to" << shortcutIconUrl;
+            //qCDebug(KWEBKITPART_LOG) << "setting favicon to" << shortcutIconUrl;
             m_browserExtension->setIconUrl(shortcutIconUrl);
         }
     }
@@ -600,7 +591,7 @@ void KWebKitPart::slotUrlChanged(const QUrl& url)
 
     // Do not update the location bar with about:blank
     if (url != *globalBlankUrl) {
-        //kDebug() << "Setting location bar to" << u.prettyUrl() << "current URL:" << this->url();
+        //qCDebug(KWEBKITPART_LOG) << "Setting location bar to" << u.prettyUrl() << "current URL:" << this->url();
         emit m_browserExtension->setLocationBarUrl(u.toDisplayString());
     }
 }
@@ -652,7 +643,7 @@ void KWebKitPart::slotSaveFrameState(QWebFrame *frame, QWebHistoryItem *item)
 
         // Only emit open url notify for the main frame. Do not
         if (m_emitOpenUrlNotify && !doNotEmitOpenUrl) {
-            // kDebug() << "***** EMITTING openUrlNotify" << item->url();
+            // qCDebug(KWEBKITPART_LOG) << "***** EMITTING openUrlNotify" << item->url();
             emit m_browserExtension->openUrlNotify();
         }
     }
@@ -663,7 +654,7 @@ void KWebKitPart::slotSaveFrameState(QWebFrame *frame, QWebHistoryItem *item)
     // slotRestoreFrameState.
     const QPoint scrollPos (frame->scrollPosition());
     if (!scrollPos.isNull()) {
-        // kDebug() << "Saving scroll position:" << scrollPos;
+        // qCDebug(KWEBKITPART_LOG) << "Saving scroll position:" << scrollPos;
         item->setUserData(scrollPos);
     }
 }
@@ -717,7 +708,7 @@ void KWebKitPart::slotLinkHovered(const QString& _link, const QString& /*title*/
 
             for(int i = 0; i < count; ++i) {
                 const QPair<QString, QString> queryItem (queryItems.at(i));
-                //kDebug() << "query: " << queryItem.first << queryItem.second;
+                //qCDebug(KWEBKITPART_LOG) << "query: " << queryItem.first << queryItem.second;
                 if (queryItem.first.contains(QL1C('@')) && queryItem.second.isEmpty())
                     fields["to"] << queryItem.first;
                 if (QString::compare(queryItem.first, QL1S("to"), Qt::CaseInsensitive) == 0)
@@ -775,7 +766,7 @@ void KWebKitPart::slotSearchForText(const QString &text, bool backward)
     if (m_searchBar->highlightMatches())
         flags |= QWebPage::HighlightAllOccurrences;
 
-    //kDebug() << "search for text:" << text << ", backward ?" << backward;
+    //qCDebug(KWEBKITPART_LOG) << "search for text:" << text << ", backward ?" << backward;
     m_searchBar->setFoundMatch(page()->findText(text, flags));
 }
 
@@ -883,7 +874,7 @@ void KWebKitPart::slotSetTextEncoding(QTextCodec * codec)
     if (!localSettings)
         return;
 
-    kDebug() << "Encoding: new=>" << localSettings->defaultTextEncoding() << ", old=>" << codec->name();
+    qCDebug(KWEBKITPART_LOG) << "Encoding: new=>" << localSettings->defaultTextEncoding() << ", old=>" << codec->name();
 
     localSettings->setDefaultTextEncoding(codec->name());
     page()->triggerAction(QWebPage::Reload);
@@ -964,7 +955,7 @@ void KWebKitPart::slotSaveFormDataRequested (const QString& key, const QUrl& url
         m_passwordBar = new PasswordBar(widget());
         KWebWallet* wallet = page()->wallet();
         if (!wallet) {
-            kWarning() << "No wallet instance found! This should never happen!";
+            qCWarning(KWEBKITPART_LOG) << "No wallet instance found! This should never happen!";
             return;
         }
         connect(m_passwordBar, SIGNAL(saveFormDataAccepted(QString)),
