@@ -22,6 +22,7 @@
 
 #include "webpage.h"
 
+#include "kwebkitpart_debug.h"
 #include "kwebkitpart.h"
 #include "websslinfo.h"
 #include "webview.h"
@@ -30,26 +31,23 @@
 #include "settings/webkitsettings.h"
 #include "webpluginfactory.h"
 
-#include <kdeversion.h>
-#include <KDE/KMessageBox>
-#include <KDE/KGlobalSettings>
-#include <KDE/KGlobal>
-#include <KDE/KLocale>
-#include <KDE/KRun>
-#include <KDE/KShell>
-#include <KDE/KStandardDirs>
-#include <KDE/KAuthorized>
-#include <KDE/KDebug>
-#include <KDE/KFileDialog>
-#include <KDE/KProtocolInfo>
-#include <KDE/KStringHandler>
-#include <KDE/KIconLoader>
-#include <KDE/KMimeType>
-#include <KDE/KUrlAuthorized>
+#include <KIconLoader>
+#include <KMessageBox>
+#include <KLocale>
+#include <KRun>
+#include <KShell>
+
+#include <KAuthorized>
+#include <KFileDialog>
+#include <KProtocolInfo>
+#include <KStringHandler>
+#include <KMimeType>
+#include <KUrlAuthorized>
 #include <KIO/Job>
 #include <KIO/AccessManager>
 #include <KIO/Scheduler>
 #include <KParts/HtmlExtension>
+#include <KSharedConfig>
 
 #include <QFile>
 #include <QApplication>
@@ -60,6 +58,8 @@
 #include <QWebHistory>
 #include <QWebHistoryItem>
 #include <QWebSecurityOrigin>
+#include <QDesktopWidget>
+#include <QStandardPaths>
 
 #define QL1S(x)  QLatin1String(x)
 #define QL1C(x)  QLatin1Char(x)
@@ -124,7 +124,7 @@ WebPage::WebPage(KWebKitPart *part, QWidget *parent)
 
 WebPage::~WebPage()
 {
-    //kDebug() << this;
+    //qCDebug(KWEBKITPART_LOG) << this;
 }
 
 const WebSslInfo& WebPage::sslInfo() const
@@ -140,13 +140,12 @@ void WebPage::setSslInfo (const WebSslInfo& info)
 static void checkForDownloadManager(QWidget* widget, QString& cmd)
 {
     cmd.clear();
-    KGlobal::locale();
     KConfigGroup cfg (KSharedConfig::openConfig("konquerorrc", KConfig::NoGlobals), "HTML Settings");
     const QString fileName (cfg.readPathEntry("DownloadManager", QString()));
     if (fileName.isEmpty())
         return;
 
-    const QString exeName = KStandardDirs::findExe(fileName);
+    const QString exeName = QStandardPaths::findExecutable(fileName);
     if (exeName.isEmpty()) {
         KMessageBox::detailedSorry(widget,
                                    i18n("The download manager (%1) could not be found in your installation.", fileName),
@@ -168,7 +167,7 @@ void WebPage::downloadRequest(const QNetworkRequest &request)
         QString managerExe;
         checkForDownloadManager(view(), managerExe);
         if (!managerExe.isEmpty()) {
-            //kDebug() << "Calling command" << cmd;
+            //qCDebug(KWEBKITPART_LOG) << "Calling command" << cmd;
             KRun::runCommand((managerExe + QLatin1Char(' ') + KShell::quoteArg(url.url())), view());
             return;
         }
@@ -204,7 +203,7 @@ QString WebPage::errorPage(int code, const QString& text, const QUrl& reqUrl) co
 
     stream >> errorName >> techName >> description >> causes >> solutions;
 
-    QFile file (KStandardDirs::locate ("data", QL1S("kwebkitpart/error.html")));
+    QFile file (QStandardPaths::locate(QStandardPaths::GenericDataLocation, QL1S("kwebkitpart/error.html")));
     if ( !file.open( QIODevice::ReadOnly ) )
         return i18n("<html><body><h3>Unable to display error message</h3>"
                     "<p>The error template file <em>error.html</em> could not be "
@@ -232,25 +231,25 @@ QString WebPage::errorPage(int code, const QString& text, const QUrl& reqUrl) co
     doc += i18n( "Details of the Request:" );
     doc += QL1S( "</h3><ul><li>" );
     // escape URL twice: once for i18n, and once for HTML.
-    doc += i18n( "URL: %1", Qt::escape( Qt::escape( reqUrl.toDisplayString() ) ) );
+    doc += i18n( "URL: %1", reqUrl.toDisplayString().toHtmlEscaped().toHtmlEscaped() );
     doc += QL1S( "</li><li>" );
 
     const QString protocol (reqUrl.scheme());
     if ( !protocol.isNull() ) {
         // escape protocol twice: once for i18n, and once for HTML.
-        doc += i18n( "Protocol: %1", Qt::escape( Qt::escape( protocol ) ) );
+        doc += i18n( "Protocol: %1", protocol.toHtmlEscaped().toHtmlEscaped() );
         doc += QL1S( "</li><li>" );
     }
 
     doc += i18n( "Date and Time: %1",
-                 KGlobal::locale()->formatDateTime(QDateTime::currentDateTime(), KLocale::LongDate) );
+                 KLocale::global()->formatDateTime(QDateTime::currentDateTime(), KLocale::LongDate) );
     doc += QL1S( "</li><li>" );
     // escape text twice: once for i18n, and once for HTML.
-    doc += i18n( "Additional Information: %1", Qt::escape( Qt::escape( text ) ) );
+    doc += i18n( "Additional Information: %1", text.toHtmlEscaped().toHtmlEscaped() );
     doc += QL1S( "</li></ul><h3>" );
     doc += i18n( "Description:" );
     doc += QL1S( "</h3><p>" );
-    doc += Qt::escape( description );
+    doc += description.toHtmlEscaped();
     doc += QL1S( "</p>" );
 
     if ( causes.count() ) {
@@ -312,7 +311,7 @@ bool WebPage::extension(Extension extension, const ExtensionOption *option, Exte
 
 bool WebPage::supportsExtension(Extension extension) const
 {
-    //kDebug() << extension << m_ignoreError;
+    //qCDebug(KWEBKITPART_LOG) << extension << m_ignoreError;
     switch (extension) {
     case QWebPage::ErrorPageExtension:
         return (!m_ignoreError);
@@ -327,7 +326,7 @@ bool WebPage::supportsExtension(Extension extension) const
 
 QWebPage *WebPage::createWindow(WebWindowType type)
 {
-    // kDebug() << "window type:" << type;
+    // qCDebug(KWEBKITPART_LOG) << "window type:" << type;
     // Crete an instance of NewWindowPage class to capture all the
     // information we need to create a new window. See documentation of
     // the class for more information...
@@ -412,10 +411,10 @@ bool WebPage::acceptNavigationRequest(QWebFrame *frame, const QNetworkRequest &r
             // If history navigation is locked, ignore all such requests...
             if (property("HistoryNavigationLocked").toBool()) {
                 setProperty("HistoryNavigationLocked", QVariant());
-                kDebug() << "Rejected history navigation because 'HistoryNavigationLocked' property is set!";
+                qCDebug(KWEBKITPART_LOG) << "Rejected history navigation because 'HistoryNavigationLocked' property is set!";
                 return false;
             }
-            //kDebug() << "Navigating to item (" << history()->currentItemIndex()
+            //qCDebug(KWEBKITPART_LOG) << "Navigating to item (" << history()->currentItemIndex()
             //         << "of" << history()->count() << "):" << history()->currentItem().url();
             inPageRequest = false;
             if (!isBlankUrl(reqUrl)) {
@@ -553,7 +552,7 @@ void WebPage::slotRequestFinished(QNetworkReply *reply)
     }
 
     const int errCode = errorCodeFromReply(reply);
-    kDebug() << frame << "is main frame request?" << isMainFrameRequest << requestUrl;
+    qCDebug(KWEBKITPART_LOG) << frame << "is main frame request?" << isMainFrameRequest << requestUrl;
     // Handle any error...
     switch (errCode) {
         case 0:
@@ -566,7 +565,7 @@ void WebPage::slotRequestFinished(QNetworkReply *reply)
             break;
         case KIO::ERR_ABORTED:
         case KIO::ERR_USER_CANCELED: // Do nothing if request is cancelled/aborted
-            //kDebug() << "User aborted request!";
+            //qCDebug(KWEBKITPART_LOG) << "User aborted request!";
             m_ignoreError = true;
             emit loadAborted(QUrl());
             return;
@@ -595,7 +594,7 @@ void WebPage::slotRequestFinished(QNetworkReply *reply)
 
 void WebPage::slotUnsupportedContent(QNetworkReply* reply)
 {
-    //kDebug() << reply->url();
+    //qCDebug(KWEBKITPART_LOG) << reply->url();
     QString mimeType;
     KIO::MetaData metaData;
 
@@ -619,7 +618,7 @@ void WebPage::slotUnsupportedContent(QNetworkReply* reply)
         return;
     }
 
-    //kDebug() << "mimetype=" << mimeType << "metadata:" << metaData;
+    //qCDebug(KWEBKITPART_LOG) << "mimetype=" << mimeType << "metadata:" << metaData;
 
     if (reply->request().originatingObject() == this->mainFrame()) {
         KParts::OpenUrlArguments args;
@@ -681,19 +680,19 @@ void WebPage::slotGeometryChangeRequested(const QRect & rect)
     // parts of following code are based on kjs_window.cpp
     // Security check: within desktop limits and bigger than 100x100 (per spec)
     if (width < 100 || height < 100) {
-        kWarning() << "Window resize refused, window would be too small (" << width << "," << height << ")";
+        qCWarning(KWEBKITPART_LOG) << "Window resize refused, window would be too small (" << width << "," << height << ")";
         return;
     }
 
-    QRect sg = KGlobalSettings::desktopGeometry(view());
+    QRect sg = QApplication::desktop()->screenGeometry(view());
 
     if (width > sg.width() || height > sg.height()) {
-        kWarning() << "Window resize refused, window would be too big (" << width << "," << height << ")";
+        qCWarning(KWEBKITPART_LOG) << "Window resize refused, window would be too big (" << width << "," << height << ")";
         return;
     }
 
     if (WebKitSettings::self()->windowResizePolicy(host) == KParts::HtmlSettingsInterface::JSWindowResizeAllow) {
-        //kDebug() << "resizing to " << width << "x" << height;
+        //qCDebug(KWEBKITPART_LOG) << "resizing to " << width << "x" << height;
         emit m_part->browserExtension()->resizeTopLevelWidget(width, height);
     }
 
@@ -716,7 +715,7 @@ bool WebPage::checkLinkSecurity(const QNetworkRequest &req, NavigationType type)
     // Check whether the request is authorized or not...
     if (!KUrlAuthorized::authorizeUrlAction("redirect", mainFrame()->url(), req.url())) {
 
-        //kDebug() << "*** Failed security check: base-url=" << mainFrame()->url() << ", dest-url=" << req.url();
+        //qCDebug(KWEBKITPART_LOG) << "*** Failed security check: base-url=" << mainFrame()->url() << ", dest-url=" << req.url();
         QString buttonText, title, message;
 
         int response = KMessageBox::Cancel;
@@ -730,7 +729,7 @@ bool WebPage::checkLinkSecurity(const QNetworkRequest &req, NavigationType type)
         } else {
             title = i18n("Security Alert");
             message = i18n("<qt>Access by untrusted page to<br/><b>%1</b><br/> denied.</qt>",
-                           Qt::escape(linkUrl.toDisplayString()));
+                           linkUrl.toDisplayString().toHtmlEscaped());
         }
 
         if (buttonText.isEmpty()) {
@@ -850,7 +849,7 @@ bool WebPage::handleMailToUrl (const QUrl &url, NavigationType type) const
                  break;
         }
 
-        //kDebug() << "Emitting openUrlRequest with " << mailtoUrl;
+        //qCDebug(KWEBKITPART_LOG) << "Emitting openUrlRequest with " << mailtoUrl;
         emit m_part->browserExtension()->openUrlRequest(mailtoUrl);
         return true;
     }
@@ -893,12 +892,12 @@ NewWindowPage::NewWindowPage(WebWindowType type, KWebKitPart* part, bool disable
 
 NewWindowPage::~NewWindowPage()
 {
-    //kDebug() << this;
+    //qCDebug(KWEBKITPART_LOG) << this;
 }
 
 bool NewWindowPage::acceptNavigationRequest(QWebFrame *frame, const QNetworkRequest &request, NavigationType type)
 {
-    // kDebug() << "url:" << request.url() << ",type:" << type << ",frame:" << frame;
+    // qCDebug(KWEBKITPART_LOG) << "url:" << request.url() << ",type:" << type << ",frame:" << frame;
     if (m_createNewWindow) {
         const QUrl reqUrl (request.url());
 
@@ -915,7 +914,7 @@ bool NewWindowPage::acceptNavigationRequest(QWebFrame *frame, const QNetworkRequ
                                                "Do you want to allow this?") :
                                           i18n("<qt>This site is requesting to open a popup window to"
                                                "<p>%1</p><br/>Do you want to allow this?</qt>",
-                                               KStringHandler::rsqueeze(Qt::escape(reqUrl.toDisplayString()), 100)));
+                                               KStringHandler::rsqueeze(reqUrl.toDisplayString().toHtmlEscaped(), 100)));
                 if (KMessageBox::questionYesNo(view(), message,
                                                i18n("Javascript Popup Confirmation"),
                                                KGuiItem(i18n("Allow")),
@@ -950,7 +949,7 @@ bool NewWindowPage::acceptNavigationRequest(QWebFrame *frame, const QNetworkRequ
 
         KParts::ReadOnlyPart* newWindowPart =0;
         part()->browserExtension()->createNewWindow(QUrl(), uargs, bargs, wargs, &newWindowPart);
-        kDebug() << "Created new window" << newWindowPart;
+        qCDebug(KWEBKITPART_LOG) << "Created new window" << newWindowPart;
 
         if (!newWindowPart) {
             return false;
@@ -1003,26 +1002,26 @@ void NewWindowPage::slotGeometryChangeRequested(const QRect & rect)
 
 void NewWindowPage::slotMenuBarVisibilityChangeRequested(bool visible)
 {
-    //kDebug() << visible;
+    //qCDebug(KWEBKITPART_LOG) << visible;
     m_windowArgs.setMenuBarVisible(visible);
 }
 
 void NewWindowPage::slotStatusBarVisibilityChangeRequested(bool visible)
 {
-    //kDebug() << visible;
+    //qCDebug(KWEBKITPART_LOG) << visible;
     m_windowArgs.setStatusBarVisible(visible);
 }
 
 void NewWindowPage::slotToolBarVisibilityChangeRequested(bool visible)
 {
-    //kDebug() << visible;
+    //qCDebug(KWEBKITPART_LOG) << visible;
     m_windowArgs.setToolBarsVisible(visible);
 }
 
 void NewWindowPage::slotLoadFinished(bool ok)
 {
     Q_UNUSED(ok)
-    //kDebug() << ok;
+    //qCDebug(KWEBKITPART_LOG) << ok;
     if (!m_createNewWindow)
         return;
 
@@ -1043,7 +1042,7 @@ void NewWindowPage::slotLoadFinished(bool ok)
     KParts::ReadOnlyPart* newWindowPart =0;
     part()->browserExtension()->createNewWindow(QUrl(), uargs, bargs, wargs, &newWindowPart);
 
-    kDebug() << "Created new window" << newWindowPart;
+    qCDebug(KWEBKITPART_LOG) << "Created new window" << newWindowPart;
 
     // Get the webview...
     KWebKitPart* webkitPart = newWindowPart ? qobject_cast<KWebKitPart*>(newWindowPart) : 0;
